'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var accounts = require('./accounts.cjs');
var Listing = require('./Listing.cjs');
var pdas = require('./pdas.cjs');
var Operation = require('../../types/Operation.cjs');

// Operation
// -----------------

const Key = 'FindListingByAddressOperation';
const findListingByAddressOperation = Operation.useOperation(Key);
// -----------------
// Handler
// -----------------
const findListingByAddressOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      address,
      auctionHouse,
      commitment,
      loadJsonMetadata = true
    } = operation.input;
    const receiptAddress = pdas.findListingReceiptPda(address);
    const account = accounts.toListingReceiptAccount(await metaplex.rpc().getAccount(receiptAddress, commitment));
    const tokenModel = await metaplex.nfts().findTokenWithMetadataByMetadata(account.data.metadata, account.data.seller, {
      commitment,
      loadJsonMetadata
    }).run(scope);
    return Listing.toListing(account, auctionHouse, tokenModel);
  }
};

exports.findListingByAddressOperation = findListingByAddressOperation;
exports.findListingByAddressOperationHandler = findListingByAddressOperationHandler;
//# sourceMappingURL=findListingByAddress.cjs.map
