'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var lplCandyMachine = require('@leda-mint-io/lpl-candy-machine');
var Amount = require('../../types/Amount.cjs');
var PublicKey = require('../../types/PublicKey.cjs');
var BigNumber = require('../../types/BigNumber.cjs');
var DateTime = require('../../types/DateTime.cjs');

const toCandyMachineConfigsFromJson = config => {
  const configCreators = config.creators ?? [{
    address: config.solTreasuryAccount,
    verified: false,
    share: 100
  }];
  return {
    wallet: config.splToken && config.splTokenAccount ? PublicKey.toPublicKey(config.splTokenAccount) : PublicKey.toPublicKey(config.solTreasuryAccount),
    tokenMint: config.splToken && config.splTokenAccount ? PublicKey.toPublicKey(config.splToken) : null,
    price: Amount.sol(config.price),
    symbol: config.symbol ?? '',
    sellerFeeBasisPoints: config.sellerFeeBasisPoints,
    maxEditionSupply: BigNumber.toBigNumber(config.maxEditionSupply ?? 0),
    isMutable: !config.noMutable,
    retainAuthority: !config.noRetainAuthority,
    goLiveDate: DateTime.toOptionDateTime(config.goLiveDate),
    itemsAvailable: BigNumber.toBigNumber(config.number),
    endSettings: config.endSettings ? config.endSettings.endSettingType === 'date' ? {
      endSettingType: lplCandyMachine.EndSettingType.Date,
      date: DateTime.toDateTime(config.endSettings.value)
    } : {
      endSettingType: lplCandyMachine.EndSettingType.Amount,
      number: BigNumber.toBigNumber(config.endSettings.value)
    } : null,
    hiddenSettings: config.hiddenSettings ? { ...config.hiddenSettings,
      hash: Buffer.from(config.hiddenSettings.hash, 'utf8').toJSON().data
    } : null,
    whitelistMintSettings: config.whitelistMintSettings ? { ...config.whitelistMintSettings,
      mode: config.whitelistMintSettings.mode === 'burnEveryTime' ? lplCandyMachine.WhitelistMintMode.BurnEveryTime : lplCandyMachine.WhitelistMintMode.NeverBurn,
      mint: PublicKey.toPublicKey(config.whitelistMintSettings.mint),
      discountPrice: Amount.sol(config.whitelistMintSettings.discountPrice)
    } : null,
    gatekeeper: config.gatekeeper ? { ...config.gatekeeper,
      network: PublicKey.toPublicKey(config.gatekeeper.gatekeeperNetwork)
    } : null,
    creators: configCreators.map(creatorConfig => ({ ...creatorConfig,
      address: PublicKey.toPublicKey(creatorConfig.address)
    }))
  };
};

exports.toCandyMachineConfigsFromJson = toCandyMachineConfigsFromJson;
//# sourceMappingURL=CandyMachineJsonConfigs.cjs.map
