'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var lplTokenMetadata = require('@leda-mint-io/lpl-token-metadata');
var Account = require('../../types/Account.cjs');

const parseMetadataAccount = Account.getAccountParsingFunction(lplTokenMetadata.Metadata);
const toMetadataAccount = Account.getAccountParsingAndAssertingFunction(lplTokenMetadata.Metadata);
const originalOrPrintEditionAccountParser = {
  name: 'MasterEditionV1 | MasterEditionV2 | Edition',
  deserialize: (data, offset = 0) => {
    if (data?.[0] === lplTokenMetadata.Key.MasterEditionV1) {
      return lplTokenMetadata.MasterEditionV1.deserialize(data, offset);
    } else if (data?.[0] === lplTokenMetadata.Key.MasterEditionV2) {
      return lplTokenMetadata.MasterEditionV2.deserialize(data, offset);
    } else {
      return lplTokenMetadata.Edition.deserialize(data, offset);
    }
  }
};
const parseOriginalOrPrintEditionAccount = Account.getAccountParsingFunction(originalOrPrintEditionAccountParser);
const toOriginalOrPrintEditionAccount = Account.getAccountParsingAndAssertingFunction(originalOrPrintEditionAccountParser);
const isOriginalEditionAccount = account => {
  return 'maxSupply' in account.data;
};
const isPrintEditionAccount = account => {
  return !isOriginalEditionAccount(account);
};
const originalEditionAccountParser = {
  name: 'MasterEditionV1 | MasterEditionV2',
  deserialize: (data, offset = 0) => {
    if (data?.[0] === lplTokenMetadata.Key.MasterEditionV1) {
      return lplTokenMetadata.MasterEditionV1.deserialize(data, offset);
    } else {
      return lplTokenMetadata.MasterEditionV2.deserialize(data, offset);
    }
  }
};
const parseOriginalEditionAccount = Account.getAccountParsingFunction(originalEditionAccountParser);
const toOriginalEditionAccount = Account.getAccountParsingAndAssertingFunction(originalEditionAccountParser);
const parsePrintEditionAccount = Account.getAccountParsingFunction(lplTokenMetadata.Edition);
const toPrintEditionAccount = Account.getAccountParsingAndAssertingFunction(lplTokenMetadata.Edition);

exports.isOriginalEditionAccount = isOriginalEditionAccount;
exports.isPrintEditionAccount = isPrintEditionAccount;
exports.parseMetadataAccount = parseMetadataAccount;
exports.parseOriginalEditionAccount = parseOriginalEditionAccount;
exports.parseOriginalOrPrintEditionAccount = parseOriginalOrPrintEditionAccount;
exports.parsePrintEditionAccount = parsePrintEditionAccount;
exports.toMetadataAccount = toMetadataAccount;
exports.toOriginalEditionAccount = toOriginalEditionAccount;
exports.toOriginalOrPrintEditionAccount = toOriginalOrPrintEditionAccount;
exports.toPrintEditionAccount = toPrintEditionAccount;
//# sourceMappingURL=accounts.cjs.map
