'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var MetaplexFile = require('./MetaplexFile.cjs');
var SdkError = require('../../errors/SdkError.cjs');

class StorageClient {
  _driver = null;

  driver() {
    if (!this._driver) {
      throw new SdkError.DriverNotProvidedError('StorageDriver');
    }

    return this._driver;
  }

  setDriver(newDriver) {
    this._driver = newDriver;
  }

  getUploadPriceForBytes(bytes) {
    return this.driver().getUploadPrice(bytes);
  }

  getUploadPriceForFile(file) {
    return this.getUploadPriceForFiles([file]);
  }

  getUploadPriceForFiles(files) {
    return this.getUploadPriceForBytes(MetaplexFile.getBytesFromMetaplexFiles(...files));
  }

  upload(file) {
    return this.driver().upload(file);
  }

  uploadAll(files) {
    const driver = this.driver();
    return driver.uploadAll ? driver.uploadAll(files) : Promise.all(files.map(file => this.driver().upload(file)));
  }

  uploadJson(json) {
    return this.upload(MetaplexFile.toMetaplexFileFromJson(json));
  }

  async download(uri, options) {
    const driver = this.driver();

    if (driver.download) {
      return driver.download(uri, options);
    }

    const response = await fetch(uri, options);
    const buffer = await response.arrayBuffer();
    return MetaplexFile.toMetaplexFile(buffer, uri);
  }

  async downloadJson(uri, options) {
    const file = await this.download(uri, options);

    try {
      return JSON.parse(file.buffer.toString());
    } catch (error) {
      throw new SdkError.InvalidJsonStringError(error);
    }
  }

}

exports.StorageClient = StorageClient;
//# sourceMappingURL=StorageClient.cjs.map
