'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var web3_js = require('@safecoin/web3.js');
var Operation = require('../../types/Operation.cjs');
var Amount = require('../../types/Amount.cjs');
var TransactionBuilder = require('../../utils/TransactionBuilder.cjs');

const Key = 'TransferSolOperation';
const transferSolOperation = Operation.useOperation(Key);
const transferSolOperationHandler = {
  async handle(operation, metaplex, scope) {
    const builder = transferSolBuilder(metaplex, operation.input);
    return builder.sendAndConfirm(metaplex, operation.input.confirmOptions);
  }

}; // -----------------
// Builder
// -----------------

const transferSolBuilder = (metaplex, params) => {
  const {
    from = metaplex.identity(),
    to,
    amount,
    basePubkey,
    seed,
    program = web3_js.SystemProgram.programId
  } = params;
  Amount.assertSol(amount);
  return TransactionBuilder.TransactionBuilder.make().add({
    instruction: web3_js.SystemProgram.transfer({
      fromPubkey: from.publicKey,
      toPubkey: to,
      lamports: amount.basisPoints.toNumber(),
      ...(basePubkey ? {
        basePubkey,
        seed
      } : {}),
      programId: program
    }),
    signers: [from],
    key: params.instructionKey ?? 'transferSol'
  });
};

exports.transferSolBuilder = transferSolBuilder;
exports.transferSolOperation = transferSolOperation;
exports.transferSolOperationHandler = transferSolOperationHandler;
//# sourceMappingURL=transferSol.cjs.map
