'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var safeToken = require('@safecoin/safe-token');
var TokenClient = require('./TokenClient.cjs');
var createMint = require('./createMint.cjs');
var createToken = require('./createToken.cjs');
var createTokenWithMint = require('./createTokenWithMint.cjs');
var findMintByAddress = require('./findMintByAddress.cjs');
var findTokenByAddress = require('./findTokenByAddress.cjs');
var findTokenWithMintByAddress = require('./findTokenWithMintByAddress.cjs');
var findTokenWithMintByMint = require('./findTokenWithMintByMint.cjs');
var mintTokens = require('./mintTokens.cjs');
var sendTokens = require('./sendTokens.cjs');

const tokenModule = () => ({
  install(metaplex) {
    // Program.
    metaplex.programs().register({
      name: 'TokenProgram',
      address: safeToken.TOKEN_PROGRAM_ID
    }); // Operations.

    const op = metaplex.operations();
    op.register(createMint.createMintOperation, createMint.createMintOperationHandler);
    op.register(createToken.createTokenOperation, createToken.createTokenOperationHandler);
    op.register(createTokenWithMint.createTokenWithMintOperation, createTokenWithMint.createTokenWithMintOperationHandler);
    op.register(findMintByAddress.findMintByAddressOperation, findMintByAddress.findMintByAddressOperationHandler);
    op.register(findTokenByAddress.findTokenByAddressOperation, findTokenByAddress.findTokenByAddressOperationHandler);
    op.register(findTokenWithMintByAddress.findTokenWithMintByAddressOperation, findTokenWithMintByAddress.findTokenWithMintByAddressOperationHandler);
    op.register(findTokenWithMintByMint.findTokenWithMintByMintOperation, findTokenWithMintByMint.findTokenWithMintByMintOperationHandler);
    op.register(mintTokens.mintTokensOperation, mintTokens.mintTokensOperationHandler);
    op.register(sendTokens.sendTokensOperation, sendTokens.sendTokensOperationHandler);

    metaplex.tokens = function () {
      return new TokenClient.TokenClient(this);
    };
  }

});

exports.tokenModule = tokenModule;
//# sourceMappingURL=plugin.cjs.map
