import { cusper } from '@leda-mint-io/lpl-auction-house';
import { AuctionsClient } from './AuctionsClient.mjs';
import { AuctionHouseProgram } from './program.mjs';
import { createAuctionHouseOperation, createAuctionHouseOperationHandler } from './createAuctionHouse.mjs';
import { createListingOperation, createListingOperationHandler } from './createListing.mjs';
import { findAuctionHouseByAddressOperation, findAuctionHouseByAddressOperationHandler } from './findAuctionHouseByAddress.mjs';
import { updateAuctionHouseOperation, updateAuctionHouseOperationHandler } from './updateAuctionHouse.mjs';
import { loadListingOperation, loadListingOperationHandler } from './loadListing.mjs';
import { findListingByAddressOperation, findListingByAddressOperationHandler } from './findListingByAddress.mjs';
import { findBidByAddressOperation, findBidByAddressOperationHandler } from './findBidByAddress.mjs';
import { loadBidOperation, loadBidOperationHandler } from './loadBid.mjs';
import { createBidOperation, createBidOperationHandler } from './createBid.mjs';

const auctionHouseModule = () => ({
  install(metaplex) {
    // Auction House Program.
    metaplex.programs().register({
      name: 'AuctionHouseProgram',
      address: AuctionHouseProgram.publicKey,
      errorResolver: error => cusper.errorFromProgramLogs(error.logs, false)
    });
    const op = metaplex.operations();
    op.register(createAuctionHouseOperation, createAuctionHouseOperationHandler);
    op.register(createBidOperation, createBidOperationHandler);
    op.register(createListingOperation, createListingOperationHandler);
    op.register(findAuctionHouseByAddressOperation, findAuctionHouseByAddressOperationHandler);
    op.register(findBidByAddressOperation, findBidByAddressOperationHandler);
    op.register(findListingByAddressOperation, findListingByAddressOperationHandler);
    op.register(loadBidOperation, loadBidOperationHandler);
    op.register(loadListingOperation, loadListingOperationHandler);
    op.register(updateAuctionHouseOperation, updateAuctionHouseOperationHandler);

    metaplex.auctions = function () {
      return new AuctionsClient(this);
    };
  }

});

export { auctionHouseModule };
//# sourceMappingURL=plugin.mjs.map
