import { AssetNotFoundError } from '../../errors/SdkError.mjs';
import { toBigNumber } from '../../types/BigNumber.mjs';
import { lamports } from '../../types/Amount.mjs';

const DEFAULT_BASE_URL = 'https://mockstorage.example.com/';
const DEFAULT_COST_PER_BYTE = 1;
class MockStorageDriver {
  cache = {};

  constructor(options) {
    this.baseUrl = options?.baseUrl ?? DEFAULT_BASE_URL;
    this.costPerByte = toBigNumber(options?.costPerByte != null ? options?.costPerByte : DEFAULT_COST_PER_BYTE);
  }

  async getUploadPrice(bytes) {
    return lamports(this.costPerByte.muln(bytes));
  }

  async upload(file) {
    const uri = `${this.baseUrl}${file.uniqueName}`;
    this.cache[uri] = file;
    return uri;
  }

  async download(uri) {
    const file = this.cache[uri];

    if (!file) {
      throw new AssetNotFoundError(uri);
    }

    return file;
  }

}

export { MockStorageDriver };
//# sourceMappingURL=MockStorageDriver.mjs.map
