import { toLazyMetadata, toMintWithMetadata } from './Metadata.mjs';
import { toMetadataAccount } from './accounts.mjs';
import { useOperation } from '../../types/Operation.mjs';
import { toMintAccount } from '../tokenModule/accounts.mjs';

// -----------------
// Operation
// -----------------
const Key = 'FindMintWithMetadataByMetadataOperation';
const findMintWithMetadataByMetadataOperation = useOperation(Key);
// -----------------
// Handler
// -----------------
const findMintWithMetadataByMetadataOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const {
      address,
      commitment,
      loadJsonMetadata = true
    } = operation.input;
    const metadataAccount = toMetadataAccount(await metaplex.rpc().getAccount(address, commitment));
    scope.throwIfCanceled();
    const mintAccount = toMintAccount(await metaplex.rpc().getAccount(metadataAccount.data.mint, commitment));
    scope.throwIfCanceled();
    let metadataModel = toLazyMetadata(metadataAccount);

    if (loadJsonMetadata) {
      metadataModel = await metaplex.nfts().loadMetadata(metadataModel).run(scope);
    }

    return toMintWithMetadata(mintAccount, metadataModel);
  }
};

export { findMintWithMetadataByMetadataOperation, findMintWithMetadataByMetadataOperationHandler };
//# sourceMappingURL=findMintWithMetadataByMetadata.mjs.map
