import { createUpdateMetadataAccountV2Instruction } from '@leda-mint-io/lpl-token-metadata';
import isEqual from 'lodash.isequal';
import { NoInstructionsToSendError } from '../../errors/SdkError.mjs';
import { useOperation } from '../../types/Operation.mjs';
import { TransactionBuilder } from '../../utils/TransactionBuilder.mjs';

// Operation
// -----------------

const Key = 'UpdateNftOperation';
const updateNftOperation = useOperation(Key);
// -----------------
// Handler
// -----------------
const updateNftOperationHandler = {
  handle: async (operation, metaplex) => {
    const builder = updateNftBuilder(metaplex, operation.input);

    if (builder.isEmpty()) {
      throw new NoInstructionsToSendError(Key);
    }

    return builder.sendAndConfirm(metaplex, operation.input.confirmOptions);
  }
}; // -----------------
// Builder
// -----------------

const updateNftBuilder = (metaplex, params) => {
  const {
    nft,
    updateAuthority = metaplex.identity()
  } = params;
  const updateInstructionDataWithoutChanges = toInstructionData(nft);
  const updateInstructionData = toInstructionData(nft, params);
  const shouldSendUpdateInstruction = !isEqual(updateInstructionData, updateInstructionDataWithoutChanges); // TODO

  return TransactionBuilder.make() // Update the metadata account.
  .when(shouldSendUpdateInstruction, builder => builder.add({
    instruction: createUpdateMetadataAccountV2Instruction({
      metadata: nft.metadataAddress,
      updateAuthority: updateAuthority.publicKey
    }, {
      updateMetadataAccountArgsV2: updateInstructionData
    }),
    signers: [updateAuthority],
    key: params.updateMetadataInstructionKey ?? 'updateMetadata'
  }));
};

const toInstructionData = (nft, input = {}) => {
  return {
    updateAuthority: input.newUpdateAuthority ?? nft.updateAuthorityAddress,
    primarySaleHappened: input.primarySaleHappened ?? nft.primarySaleHappened,
    isMutable: input.isMutable ?? nft.isMutable,
    data: {
      name: input.name ?? nft.name,
      symbol: input.symbol ?? nft.symbol,
      uri: input.uri ?? nft.uri,
      sellerFeeBasisPoints: input.sellerFeeBasisPoints ?? nft.sellerFeeBasisPoints,
      creators: input.creators ?? nft.creators,
      collection: input.collection === undefined ? nft.collection : input.collection,
      uses: input.uses === undefined ? nft.uses : input.uses
    }
  };
};

export { updateNftBuilder, updateNftOperation, updateNftOperationHandler };
//# sourceMappingURL=updateNft.mjs.map
