import { ProgramNotRecognizedError, MissingGpaBuilderError } from '../../errors/SdkError.mjs';

class ProgramClient {
  constructor(metaplex) {
    this.metaplex = metaplex;
  }

  programs = [];

  register(program) {
    this.programs.push(program);
  }

  all() {
    return this.programs;
  }

  allForCluster(cluster) {
    return this.programs.filter(program => {
      return program.clusterFilter?.(cluster) ?? true;
    });
  }

  allForCurrentCluster() {
    return this.allForCluster(this.metaplex.cluster);
  }

  get(nameOrAddress) {
    const programs = this.allForCurrentCluster();
    const program = typeof nameOrAddress === 'string' ? programs.find(program => program.name === nameOrAddress) : programs.find(program => program.address.equals(nameOrAddress));

    if (!program) {
      throw new ProgramNotRecognizedError(nameOrAddress, this.metaplex.cluster);
    }

    return program;
  }

  getGpaBuilder(nameOrAddress) {
    const program = this.get(nameOrAddress);

    if (!program.gpaResolver) {
      throw new MissingGpaBuilderError(program);
    }

    return program.gpaResolver(this.metaplex);
  }

}

export { ProgramClient };
//# sourceMappingURL=ProgramClient.mjs.map
