import { ConfirmOptions, PublicKey } from '@safecoin/web3.js';
import type { Metaplex } from "../../Metaplex";
import { TransactionBuilder, Option } from "../../utils";
import { Operation, OperationHandler, Signer, SolAmount, SplTokenAmount, Pda } from "../../types";
import { SendAndConfirmTransactionResponse } from '../rpcModule';
import { AuctionHouse } from './AuctionHouse';
declare const Key: "CreateBidOperation";
export declare const createBidOperation: import("../../types").OperationConstructor<CreateBidOperation, "CreateBidOperation", CreateBidInput, CreateBidOutput>;
export declare type CreateBidOperation = Operation<typeof Key, CreateBidInput, CreateBidOutput>;
export declare type CreateBidInput = {
    auctionHouse: AuctionHouse;
    buyer?: PublicKey | Signer;
    authority?: PublicKey | Signer;
    mintAccount: PublicKey;
    seller?: Option<PublicKey>;
    tokenAccount?: Option<PublicKey>;
    price?: SolAmount | SplTokenAmount;
    tokens?: SplTokenAmount;
    bookkeeper?: Signer;
    printReceipt?: boolean;
    confirmOptions?: ConfirmOptions;
};
export declare type CreateBidOutput = {
    response: SendAndConfirmTransactionResponse;
    buyerTradeState: Pda;
    tokenAccount: Option<PublicKey>;
    metadata: Pda;
    buyer: PublicKey;
    receipt: Pda;
    bookkeeper: PublicKey;
    price: SolAmount | SplTokenAmount;
    tokens: SplTokenAmount;
};
export declare const createBidOperationHandler: OperationHandler<CreateBidOperation>;
export declare type CreateBidBuilderParams = Omit<CreateBidInput, 'confirmOptions'> & {
    instructionKey?: string;
};
export declare type CreateBidBuilderContext = Omit<CreateBidOutput, 'response'>;
export declare const createBidBuilder: (metaplex: Metaplex, params: CreateBidBuilderParams) => Promise<TransactionBuilder<CreateBidBuilderContext>>;
export {};
